@@ -2,12 +2,15 @@ import os
 import secrets
 import sys
 
-from flask import Flask, redirect, url_for, request
+from flask import Flask, redirect, url_for, request, render_template
 from flask_babel import Babel
 from werkzeug.routing import IntegerConverter
 from werkzeug.serving import make_ssl_devcert
-from werkzeug.contrib.profiler import ProfilerMiddleware
-from werkzeug.exceptions import InternalServerError
+try:
+	from werkzeug.middleware.profiler import ProfilerMiddleware
+except ImportError:
+	from werkzeug.contrib.profiler import ProfilerMiddleware
+from werkzeug.exceptions import InternalServerError, Forbidden
 from flask_migrate import Migrate
 
 import uffd.ldap
@@ -59,6 +62,8 @@ def create_app(test_config=None): # pylint: disable=too-many-locals
 		for cfg_name in ["config.cfg", "config.json", "config.yml", "config.yaml"]:
 			if load_config_file(app, cfg_name, silent=True):
 				break
+	# Prior to v1.1 login required ACL_SELFSERVICE_GROUP and ACL_ACCESS_GROUP did not exist
+	app.config.setdefault('ACL_ACCESS_GROUP', app.config['ACL_SELFSERVICE_GROUP'])
 
 	register_template_helper(app)
 	setup_navbar(app)
@@ -71,7 +76,7 @@ def create_app(test_config=None): # pylint: disable=too-many-locals
 		pass
 
 	db.init_app(app)
-	Migrate(app, db, render_as_batch=True, directory='uffd/migrations')
+	Migrate(app, db, render_as_batch=True, directory=os.path.join(app.root_path, 'migrations'))
 
 	for i in user.bp + selfservice.bp + role.bp + mail.bp + session.bp + csrf.bp + mfa.bp + oauth2.bp + services.bp + rolemod.bp + api.bp:
 		app.register_blueprint(i)
@@ -94,6 +99,10 @@ def create_app(test_config=None): # pylint: disable=too-many-locals
 		app.test_request_context().push() # LDAP ORM requires request context
 		return {'db': db, 'ldap': uffd.ldap.ldap, 'User': User, 'Group': Group, 'Role': Role, 'Mail': Mail}
 
+	@app.errorhandler(403)
+	def handle_403(error):
+		return render_template('403.html', description=error.description if error.description != Forbidden.description else None), 403
+
 	@app.route("/")
 	def index(): #pylint: disable=unused-variable
 		return redirect(url_for('selfservice.index'))
