@@ -9,16 +9,15 @@ from uffd.session import login_required
 from uffd.mail.models import Mail
 
 bp = Blueprint("mail", __name__, template_folder='templates', url_prefix='/mail/')
-@bp.before_request
-@login_required()
-def mail_acl(): #pylint: disable=inconsistent-return-statements
-	if not mail_acl_check():
-		flash('Access denied')
-		return redirect(url_for('index'))
 
 def mail_acl_check():
 	return request.user and request.user.is_in_group(current_app.config['ACL_ADMIN_GROUP'])
 
+@bp.before_request
+@login_required(mail_acl_check)
+def mail_acl():
+	pass
+
 @bp.route("/")
 @register_navbar(29, lazy_gettext('Forwardings'), icon='envelope', blueprint=bp, visible=mail_acl_check)
 def index():
